@@ -1,5 +1,7 @@
 /*
  *  Copyright (C) 2004 Adam Hooper
+ *  Copyright (C) 2004, 2005 Jean-François Rameau
+ *  Copyright (C) 2004, 2005 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-helpers.h,v 1.11 2005/02/11 15:44:02 chpe Exp $
+ *  $Id: mozilla-helpers.h,v 1.13.2.1 2005/04/09 21:12:54 chpe Exp $
  */
 
 #ifndef PAGE_INFO_MOZILLA_HELPERS_H
@@ -70,13 +72,15 @@ typedef struct
 	*/
 } EmbedPageProperties;
 
+/* take care to sort enum by name */
+/* so we can sort media as well */
 typedef enum 
 {
-  MEDIUM_IMAGE,
-  MEDIUM_EMBED,
-  MEDIUM_OBJECT,
   MEDIUM_APPLET,
+  MEDIUM_EMBED,
   MEDIUM_ICON,
+  MEDIUM_IMAGE,
+  MEDIUM_OBJECT,
   LAST_MEDIUM
 } EmbedPageMediumType;
 
@@ -105,15 +109,21 @@ typedef struct
   char *action;
 } EmbedPageForm;
 
+typedef struct
+{
+  char *name;
+  char *content;
+} EmbedPageMetaTag;
+
 typedef struct
 {
   EmbedPageProperties *props;
   GList *media;
   GList *links;
   GList *forms;
+  GList *metatags;
 } EmbedPageInfo;
 
-
 EmbedPageInfo *mozilla_get_page_info        (EphyEmbed *embed);
 
 void           mozilla_free_embed_page_info (EmbedPageInfo *info);
